@@ -37,6 +37,7 @@ strucplot <- function(## main parameters
                       sub_gp = gpar(fontsize = 15),
                       newpage = TRUE,
                       pop = TRUE,
+                      return_grob = FALSE,
                       keep_aspect_ratio = NULL,
                       prefix = "",
                       ...
@@ -157,15 +158,15 @@ strucplot <- function(## main parameters
   FUN <- function(par) {
     if (is.structable(par))
       par <- as.table(par)
-    if (length(par) < size) aperm(array(par, dim = rev(d))) else par
+    if (length(par) < size || is.null(dim(par))) aperm(array(par, dim = rev(d))) else par
   }
   gp <- structure(lapply(gp, FUN), class = "gpar")
 
   ## set up page
   if (newpage)
-    grid.newpage()
+      grid.newpage()
   if (keep_aspect_ratio)
-    pushViewport(viewport(width = 1, height = 1, default.units = "snpc"))
+      pushViewport(viewport(width = 1, height = 1, default.units = "snpc"))
 
   pushViewport(vcdViewport(mar = margins,
                            oma = title_margins,
@@ -231,11 +232,21 @@ strucplot <- function(## main parameters
 
   seekViewport(paste(prefix, "base", sep = ""))
   ## one more up if sandwich-mode
-  if (pop) popViewport(1 + keep_aspect_ratio) else upViewport(1 + keep_aspect_ratio)
+  if (pop)
+      popViewport(1 + keep_aspect_ratio)
+  else
+      upViewport(1 + keep_aspect_ratio)
 
   ## return visualized table
-  invisible(structable(if (type == "observed") x else expected,
-                      split_vertical = split_vertical))
+  if (return_grob)
+      invisible(structure(structable(if (type == "observed") x else expected,
+                                     split_vertical = split_vertical),
+                          grob = grid.grab()
+                          )
+                )
+  else
+      invisible(structable(if (type == "observed") x else expected,
+                           split_vertical = split_vertical))
 }
 
 vcdViewport <- function(mar = rep.int(2.5, 4),
